@@ -1,4 +1,5 @@
-/* Bluefish HTML Editor - bookmarks
+/* Bluefish HTML Editor
+ * bookmark.c - bookmarks
  *
  * Copyright (C) 2003 Oskar Swida
  * modifications (C) 2004 Olivier Sessink
@@ -15,8 +16,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
+
 /* #define DEBUG */
 
 #include <gtk/gtk.h>
@@ -1025,6 +1027,7 @@ void bmark_set_for_doc(Tdocument * doc) {
 					}
 					doc->bmark_parent = g_memdup(&tmpiter, sizeof(GtkTreeIter));
 					DEBUG_MSG("bmark_set_for_doc, added parent_iter %p to doc %p\n",doc->bmark_parent,doc);
+					g_hash_table_insert(BFWIN(doc->bfwin)->bmark_files, g_strdup(mark->filepath), doc->bmark_parent);
 					return;
 				}
 			}
