@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * gtk_easy.c
  *
- * Copyright (C) 1999-2005 Olivier Sessink
+ * Copyright (C) 1999-2006 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,16 +21,16 @@
 /* #define DEBUG */
 
 #include <gtk/gtk.h>
-#include <stdlib.h> /* strtod() */
-#include <string.h> /* strlen() */
-#include <gdk/gdkkeysyms.h> /* GDK_Return */
+#include <gdk/gdkkeysyms.h>    /* GDK_Return */
+#include <stdlib.h>            /* strtod() */
+#include <string.h>            /* strlen() */
 
 #include "bluefish.h"
 #include "gtk_easy.h"
 #include "bf_lib.h"
+#include "char_table.h"    /* xml_escape() */
+#include "gui.h"           /* statusbar_message() */
 #include "pixmap.h"
-#include "gui.h" /* statusbar_message() */
-#include "char_table.h" /* xml_escape() */
 
 #ifdef WIN32
 #define DIRSTR "\\"
@@ -823,6 +823,9 @@ void bf_mnemonic_label_tad_with_alignment(const gchar *labeltext, GtkWidget *m_w
 		if (GTK_IS_COMBO(m_widget)) {
 			gtk_label_set_mnemonic_widget(GTK_LABEL(label), (GTK_COMBO(m_widget)->entry));
 			gtk_entry_set_activates_default(GTK_ENTRY(GTK_COMBO(m_widget)->entry), TRUE);
+		} else  if (GTK_IS_ENTRY(m_widget)) {
+		    gtk_label_set_mnemonic_widget(GTK_LABEL(label), m_widget);
+		    gtk_entry_set_activates_default(GTK_ENTRY(m_widget), TRUE);
 		} else gtk_label_set_mnemonic_widget(GTK_LABEL(label), m_widget);
 	}
 }
@@ -1013,7 +1016,9 @@ gint multi_button_dialog_backend(GtkWidget *win, gchar *primary, gchar *secondar
 	hig_dialog_backend (GTK_DIALOG (dialog), primary, secondary, icon);
 	gtk_widget_show_all (dialog);
 	retval = gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
+	if (retval != GTK_RESPONSE_NONE) {
+	    gtk_widget_destroy (dialog);
+	}
 
 	DEBUG_MSG("multi_button_dialog_backend: got %d\n", retval);	
 	return (retval == GTK_RESPONSE_DELETE_EVENT) ? cancelval : retval; /* When user hits escape -- give cancelval. */
@@ -1334,10 +1339,6 @@ GtkWidget *file_but_new(GtkWidget * which_entry, gint full_pathname, Tbfwin *bfw
 
 #ifdef HAVE_ATLEAST_GTK_2_4
 
-static void viewlocal_toggled_lcb(GtkToggleButton *togglebutton,GtkWidget *dialog) {
-	g_object_set(G_OBJECT(dialog), "show-hidden", togglebutton->active, NULL);
-}
-
 static void file_chooser_set_current_dir(GtkWidget *dialog, gchar *dir) {
 	if (dir) {
 		if (dir[0] == '/') gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog),dir);
@@ -1346,13 +1347,17 @@ static void file_chooser_set_current_dir(GtkWidget *dialog, gchar *dir) {
 }
 
 GtkWidget * file_chooser_dialog(Tbfwin *bfwin, gchar *title, GtkFileChooserAction action, 
-											gchar *set, gboolean localonly, gboolean multiple, const gchar *filter) {
-	GtkWidget *vbox, *hbox, *dialog, *viewlocal;
-	dialog = gtk_file_chooser_dialog_new_with_backend(title,bfwin ? GTK_WINDOW(bfwin->main_window) : NULL,
+                                gchar *set, gboolean localonly, gboolean multiple, const gchar *filter) {
+	GtkWidget *dialog;
+/*	dialog = gtk_file_chooser_dialog_new_with_backend(title,bfwin ? GTK_WINDOW(bfwin->main_window) : NULL,
 			action,"gnome-vfs",
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			(action == GTK_FILE_CHOOSER_ACTION_SAVE) ? GTK_STOCK_SAVE : GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-			NULL);
+			NULL); */
+	dialog = gtk_file_chooser_dialog_new(title,bfwin ? GTK_WINDOW(bfwin->main_window) : NULL, action,
+                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                (action == GTK_FILE_CHOOSER_ACTION_SAVE) ? GTK_STOCK_SAVE : GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER(dialog), localonly);
 	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(dialog), multiple);	
@@ -1369,6 +1374,7 @@ GtkWidget * file_chooser_dialog(Tbfwin *bfwin, gchar *title, GtkFileChooserActio
 			DEBUG_MSG("file_chooser_dialog, opendir=%s, savedir=%s\n",bfwin->session->opendir,bfwin->session->savedir);
 			if (bfwin->session->savedir) file_chooser_set_current_dir(dialog,bfwin->session->savedir);
 			else if (bfwin->session->opendir) file_chooser_set_current_dir(dialog,bfwin->session->opendir);
+			else if (bfwin->project->basedir) file_chooser_set_current_dir(dialog, bfwin->project->basedir);
 		} else {
 			DEBUG_MSG("file_chooser_dialog, opendir=%s\n",bfwin->session->opendir);
 			file_chooser_set_current_dir(dialog,bfwin->session->opendir);
@@ -1394,13 +1400,7 @@ GtkWidget * file_chooser_dialog(Tbfwin *bfwin, gchar *title, GtkFileChooserActio
 			tmplist = g_list_next(tmplist);
 		}
 	}*/
-	vbox = gtk_vbox_new(FALSE, 5);
 
-	hbox = gtk_hbox_new(FALSE, 5);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 5);
-	viewlocal = boxed_checkbut_with_value(_("Show hidden"), 0, hbox);
-	g_signal_connect(G_OBJECT(viewlocal), "toggled", G_CALLBACK(viewlocal_toggled_lcb), dialog);
-	gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(dialog),vbox);
 	if (action == GTK_FILE_CHOOSER_ACTION_OPEN || action == GTK_FILE_CHOOSER_ACTION_SAVE){
 		GList *tmplist;
 		GtkFileFilter* ff;
@@ -1432,7 +1432,7 @@ GtkWidget * file_chooser_dialog(Tbfwin *bfwin, gchar *title, GtkFileChooserActio
 			tmplist = g_list_next(tmplist);
 		}
 	}
-	gtk_widget_show_all(vbox);
+
 	return dialog;
 }
 
